Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(623)

Unified Diff: chrome/browser/ui/views/tabs/tab_drag_controller.h

Issue 2640433004: ChromeOS MD: Fix cannot drag tab onto immersive fullscreen window (Closed)
Patch Set: modify test coverage, but it is a disabled test Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/tabs/tab_drag_controller.h
diff --git a/chrome/browser/ui/views/tabs/tab_drag_controller.h b/chrome/browser/ui/views/tabs/tab_drag_controller.h
index 9bb40429e67c13859872702ee0ae3703c588d284..27b90f205eee251f9e61ed857bdb2984c5adb422 100644
--- a/chrome/browser/ui/views/tabs/tab_drag_controller.h
+++ b/chrome/browser/ui/views/tabs/tab_drag_controller.h
@@ -284,10 +284,11 @@ class TabDragController : public views::WidgetObserver,
Liveness GetTargetTabStripForPoint(const gfx::Point& point_in_screen,
TabStrip** tab_strip);
// Returns true if |tabstrip| contains the specified point in screen
// coordinates.
bool DoesTabStripContain(TabStrip* tabstrip,
- const gfx::Point& point_in_screen) const;
+ const gfx::Point& point_in_screen,
+ gfx::NativeWindow window) const;
// Returns the DetachPosition given the specified location in screen
// coordinates.
@@ -284,10 +284,11 @@ class TabDragController : public views::WidgetObserver,
Liveness GetTargetTabStripForPoint(const gfx::Point& point_in_screen,
TabStrip** tab_strip);
- // Returns true if |tabstrip| contains the specified point in screen
- // coordinates.
+ // Returns true if |window|'s |tabstrip| contains the specified point in
+ // screen coordinates.
bool DoesTabStripContain(TabStrip* tabstrip,

Powered by Google App Engine
This is Rietveld 408576698